<div align="center">
<a href="https://v2.nonebot.dev/"><img src="https://v2.nonebot.dev/logo.png" width="200" height="200" alt="nonebot"></a>

# nonebot_plugin_gakuenImasCalculator

_✨ [Nonebot2](https://github.com/nonebot/nonebot2) 插件，NoneBot2学院偶像大师(gakuenIdolMaster)算分插件  ✨_



</div> 


## 一.**安装**
### 1.使用nb-cli安装
执行
```
pip install nonebot_plugin_gakuenImasCalculator
```
然后打开 nonebot2 项目根目录下的 `pyproject.toml` 文件, 在 `[tool.nonebot]` 部分追加写入

    plugins = ["nonebot_plugin_gakuenImasCalculator"]

或其他任意加载方式



## 二.**配置**  
### 1.暂不需要配置
```

```  
## 三.**使用**  
### 
```
在群聊中输入算分与期末时的三维属性
算分 1000 1000 1000
```  
<img src="https://github.com/ikarosf/nonebot_plugin_gakuenImasCalculator/blob/main/suanfen.png" alt="寄寄子算分示例" >
```
在群聊中输入算分与期末属性截图
```  
<img src="https://github.com/ikarosf/nonebot_plugin_gakuenImasCalculator/blob/main/suanshuxingocr.png" alt="寄寄子算分示例2" >
```
在群聊中输入算属性 计算选择哪项训练能获得最高属性
```  
<img src="https://github.com/ikarosf/nonebot_plugin_gakuenImasCalculator/blob/main/suanshuxing.png" alt="寄寄子算属性示例" >